#
# spec file for package OpenIPMI
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif

# IPMI.pdf build for devel package
# It is not worth to build, but as I got it running I add it
# how it worked for me in Tumbleweed, Leap 42.2 and 42.3 and SLE 15
# latex packages where not avail for SLE 12 flavors
%define doc_build 0
%if 0%{?suse_version} < 1500
%define doc_build 0
%endif

Name:           OpenIPMI
Version:        2.0.31
Release:        5.12
Summary:        Service processor access via IPMI
License:        LGPL-2.1-or-later
Group:          System/Monitoring
URL:            http://openipmi.sourceforge.net
Source0:        http://prdownloads.sourceforge.net/openipmi/%{name}-%{version}.tar.gz
Source1:        sysconfig.ipmi
Source2:        ipmi.service
Source3:        openipmi-helper
Source4:        bootstrap
Source99:       OpenIPMI-rpmlintrc
# Patch0:         OpenIPMI-2.0.25..HEAD_git.diff
Patch1:         OpenIPMI-prefer_perl_vendor.patch
Patch2:         fix-conversions.patch
# PATCH-FIX-UPSTREAM do not use bundled libedit
# Patch3:         0003-Apply-OpenIPMI-2.0.21-nobundle.patch.patch
# PATCH-FIX-UPSTREAM detect tinfo from ncurses properly
Patch4:         openipmi-tinfo.patch
# link with ncurses
Patch5:         OpenIMPI-add-libncurses.patch
# some int functions do not return a value
Patch6:         OpenIPMI-no-return-in-nonvoid-function.patch
Patch7:         fix_dia_version_detection.patch
Patch8:         use_python3_shebang
Patch9:         lanserv-Add-the-judgment-on-the-validity-of-length-in-emu_cmd.c-and-session-in-lanserv_ipmi.c.patch
Patch10:        unix_thread-Remove-the-fd-handler-sets-before-it-s-set-up.patch
# PATCH-FIX-UPSTREAM OpenIPMI-autoconf-m4-ax-python-devel-serial25.patch
# replace autoconf script serial18 addtion by serial 25 capable of finding python3.10
# retains upstream change https://sourceforge.net/p/openipmi/code/ci/53d2b36b58383d155e2410cae3b30975a92f417d
Patch11:        OpenIPMI-autoconf-m4-ax-python-devel-serial25.patch

BuildRequires:  autoconf-archive
BuildRequires:  gd-devel
BuildRequires:  gdbm-devel
BuildRequires:  glib2-devel
BuildRequires:  libedit-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  net-snmp-devel
BuildRequires:  openssl-devel
BuildRequires:  perl-macros
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-tk
BuildRequires:  python3-xml
BuildRequires:  readline-devel
BuildRequires:  swig
BuildRequires:  systemd-rpm-macros
BuildRequires:  tcl-devel
BuildRequires:  tix
%if 0%{?doc_build}
BuildRequires:  dia
BuildRequires:  ghostscript
BuildRequires:  texlive-acronym
BuildRequires:  texlive-bibtex
BuildRequires:  texlive-dvips-bin
BuildRequires:  texlive-latex
BuildRequires:  texlive-moreverb
%endif

Requires(post): %fillup_prereq
Provides:       ipmi_ui
Provides:       ipmicmd
Provides:       ipmilan
%{?systemd_ordering}
%{?perl_requires}

%description
OpenIPMI allows access to IPMI information on a server and to abstract it.

The device driver is included in the Linux kernel, and there is a
user-level library available for it as well. This OpenIPMI package
also includes the ipmicmd program, a program that can inject and
receive messages.

%package -n libOpenIPMI0
Summary:        User-level library for accessing IPMI services
Group:          System/Libraries

%description -n libOpenIPMI0
The user-level library that provides a higher-level abstraction of
IPMI and generic services.

%package -n libOpenIPMIui1
Summary:        User-level library for accessing IPMI services
Group:          System/Libraries

%description -n libOpenIPMIui1
The user-level library that provides a higher-level abstraction of
IPMI and generic services.

%package devel
Summary:        Development files for OpenIPMI
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libOpenIPMI0 = %{version}-%{release}
Requires:       libOpenIPMIui1 = %{version}-%{release}

%description devel
These libraries are needed to get full access to the OpenIPMI
functions.

%package python3
Summary:        Python module and GUI for OpenIPMI
Group:          System/Monitoring
Requires:       OpenIPMI
Requires:       python3-tk
Requires:       tix
Provides:       openipmigui
Conflicts:      OpenIPMI-python

%description python3
The Python parts provide an OpenIPMI Python library and a GUI, openipmigui,
that makes use of it.

%prep
%autosetup -p1

rm -rf ./libedit

%build
export EDIT_CFLAGS=`pkg-config --cflags libedit`
export EDIT_LIBS=`pkg-config --libs libedit`
export CFLAGS="%{optflags} -fno-strict-aliasing"
export PYTHON_VERSION=%{python3_version}
chmod 755 %{SOURCE4}
%{SOURCE4}
%configure --disable-static \
           --with-openssl=yes \
           --with-pythoninstall=%{python3_sitearch} \
           --with-tcl=yes \
           --with-tcllibs=-ltcl%{tcl_version} \
           --with-tkinter=yes
%make_build
%if 0%{?doc_build}
cd doc
make IPMI.pdf
%endif

%install
%make_install
install -d %{buildroot}%{_fillupdir}
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sbindir}

case "%{_arch}" in
ppc64*) IPMI_SI_MODULE_NAME=ipmi_powernv;;
aarch64|arm*) IPMI_SI_MODULE_NAME=ipmi_ssif;;
*) IPMI_SI_MODULE_NAME=ipmi_si;;
esac
sed -i "s/^IPMI_SI_MODULE_NAME=.*/IPMI_SI_MODULE_NAME=\"$IPMI_SI_MODULE_NAME\"/" %{SOURCE1}
install -m 644 %{SOURCE1} %{buildroot}%{_fillupdir}

install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}
ln -sv service %{buildroot}%{_sbindir}/rcipmi
install -d %{buildroot}%{_libexecdir}
install -m 755 %{SOURCE3} %{buildroot}%{_libexecdir}/openipmi-helper
find %{buildroot} -type f -name "*.la" -delete -print

# rebuild python3 files to fix timestamps:
for d in "%{python3_sitelib}" "%{python3_sitearch}"; do
    [ -d "%{buildroot}$d" ] || continue
    find "%{buildroot}$d/" -type f \( -name '*.pyc' -o -name '*.pyo' \) -delete
    python3 -c 'import compileall; compileall.compile_dir("%{buildroot}'"$d"'",ddir="'"$d"'",force=1)'
done

%pre
%service_add_pre ipmi.service

%preun
%service_del_preun ipmi.service

%post
%fillup_only -n ipmi
%service_add_post ipmi.service

%postun
%service_del_postun ipmi.service

%post   -n libOpenIPMI0 -p /sbin/ldconfig
%postun -n libOpenIPMI0 -p /sbin/ldconfig
%post   -n libOpenIPMIui1 -p /sbin/ldconfig
%postun -n libOpenIPMIui1 -p /sbin/ldconfig

%files
%license COPYING COPYING.BSD COPYING.LIB
%doc CONFIGURING_FOR_LAN FAQ
%doc README README.Force README.MotorolaMXP
%{_fillupdir}/sysconfig.ipmi
%{_unitdir}/ipmi.service
%{_sbindir}/rcipmi
%{_libexecdir}/openipmi-helper
%dir %{_sysconfdir}/ipmi
%config(noreplace) %{_sysconfdir}/ipmi/*
###### perl files ######
%dir %{perl_vendorarch}/auto/OpenIPMI
%{perl_vendorarch}/auto/OpenIPMI/OpenIPMI.so
%{perl_vendorarch}/OpenIPMI.pm
%doc swig/perl/sample swig/perl/ipmi_powerctl
###### ui files ######
%{_bindir}/ipmi_sim

%{_bindir}/ipmi_ui
%{_bindir}/ipmicmd
%{_bindir}/openipmicmd
%{_bindir}/ipmish
%{_bindir}/openipmish
%{_bindir}/sdrcomp
%{_bindir}/solterm
%{_bindir}/rmcp_ping
%{_bindir}/openipmi_eventd
%{_mandir}/man1/ipmi_ui.1*
%{_mandir}/man1/openipmicmd.1*
%{_mandir}/man1/openipmish.1*
%{_mandir}/man1/solterm.1*
%{_mandir}/man1/openipmi_eventd.1*
%{_mandir}/man1/rmcp_ping.1*
%{_mandir}/man1/ipmi_sim.1*
%{_mandir}/man5/ipmi_lan.5*
%{_mandir}/man5/ipmi_sim_cmd.5*
%{_mandir}/man7/ipmi_cmdlang.7*
%{_mandir}/man7/openipmi_conparms.7*
###### lanserv files #####
%{_bindir}/ipmilan
%{_mandir}/man8/ipmilan.8*

%files -n libOpenIPMI0
%{_libdir}/libIPMIlanserv.so.*
%{_libdir}/libOpenIPMI.so.*
%{_libdir}/libOpenIPMIcmdlang.so.*
%{_libdir}/libOpenIPMIglib.so.*
%{_libdir}/libOpenIPMIposix.so.*
%{_libdir}/libOpenIPMIpthread.so.*
%{_libdir}/libOpenIPMIutils.so.*

%files -n libOpenIPMIui1
%{_libdir}/libOpenIPMIui.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%if 0%{?doc_build}
%doc doc/IPMI.pdf
%endif
###################################################

%files python3
%{python3_sitearch}/*OpenIPMI.*
%doc swig/OpenIPMI.i
###### gui files ######
%dir %{python3_sitearch}/openipmigui
%{python3_sitearch}/openipmigui/*
%{python3_sitearch}/__pycache__/*
%attr(755,root,root) %{_bindir}/openipmigui
%{_mandir}/man1/openipmigui.1*

%changelog
* Mon May  9 2022 Ben Greiner <code@bnavigator.de>
- Add OpenIPMI-autoconf-m4-ax-python-devel-serial25.patch
  which updates m4/ax_python_devel.m4 to serial25, retaining
  upstreams PYTHON_VERSION addition, before the bootstrap runs
  automake, because the new serial 25 can deal with
  Python 3.10 version strings and deprecation of distutils.
* Thu Apr 28 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libOpenIPMI0.x86_64: E:
  shlib-policy-name-error SONAME: libOpenIPMIui.so.1, expected
  package suffix: 1"
- Trim manual library Provides. Prospective users (packages) ought
  to let rpm find the dependencies (and their name is usually
  "libIPMIlanserv.so.0()(64bit)" not "libIPMIlanserv".
* Tue Oct 12 2021 Thomas Renninger <trenn@suse.de>
- Fix file conflict with old python2 version (bsc#1190999):
  found conflict of OpenIPMI-python-2.0.25-7.3.1.x86_64 with OpenIPMI-python3-2.0.31-1.1.x86_64
  /usr/bin/openipmigui
  /usr/share/man/man1/openipmigui.1.gz
* Wed Oct  6 2021 Thomas Renninger <trenn@suse.de>
- Enhance changelog as demanded in an internal submitrequest
* Tue Sep 28 2021 Thomas Renninger <trenn@suse.de>
- Add latest mainline fixes:
  A    lanserv-Add-the-judgment-on-the-validity-of-length-in-emu_cmd.c-and-session-in-lanserv_ipmi.c.patch
  A    unix_thread-Remove-the-fd-handler-sets-before-it-s-set-up.patch
* Fri Jul  9 2021 Thomas Renninger <trenn@suse.de>
- Update to version 2.0.31
  Adopted patches to latest sources:
  M    OpenIMPI-add-libncurses.patch
  M    OpenIPMI-no-return-in-nonvoid-function.patch
  M    OpenIPMI-prefer_perl_vendor.patch
  M    fix_dia_version_detection.patch
  M    openipmi-tinfo.patch
  * sample: Prefer glib for solterm instead of posix
  * sample: Remove -rdynamic from openipmicmd
  * smample: Compile ipmicmd with glib if it is available
  * glib: Allow NULL timeout to perform_one_op()
  * lanserv: Fix an issue with rmcp sending
  * Rework mcserv.h so that marvell-mod can get what it needs
  * lanserv: Move sol_init_mc() into sol code
  * lanserv: Remove all calls from the library to user code
  * Move ipmi_log() to ipmi_log.h
  * ui: export ipmi_ui_cb_handlers
  * ui: Add link libraries to UI library
  * Add -no-undefined to all shared library links
  * Rework ipmi_cmdlang_report_event()
  * Rework ipmi_cmdlang_global_err()
  * Get rid of posix_vlog()
  * lanserv: Use recv, not read, for a network socket
  * A lot windows (DLL, winsock, etc.) enhancements
- Update to version 2.0.30:
  * Switch to python3 by default
  * lanserv: Fix some various bugs
  * sol: Fix some various bugs
  * sdrcomp: Fix some memory leaks
  * sol: Fix some packet handling errors
  * solterm: Clean things up at shutdown
  * Fix a leak in the selector code
  * sol: Rewrite the library code
  * sol: Return errors from close if the send fails
  * Reconfigure the transmitter on a reconnect
  * Refuse writes greater than 255 bytes
  * lan: Fix timer cleanup
  * Fix init/shutdown issues with mcs and domains
  * Fix shutdown on error issues
  * Fix a memory leak at initialization
  * selector: Make the timer stop with done work right when handler running
  * Add parameters to let the lan timeouts be specified
  * initscript: Don't delete ipmi devices if udev created them
  * selector: Rework to allow an arbitrary number of fds with epoll
  * Don't disable fd handlers before setting one up
  * Don't crash if passed in fd is >= FD_SETSIZE
* Mon Jun 28 2021 Matej Cepl <mcepl@suse.com>
- Use Python3 instead of Python2 (bsc#1190999).
* Mon Mar  8 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- drop -fPIC from CFLAGS which breaks our gcc-PIE profile resulting in
  non-position independent binaries and thus weakened security (bsc#1183046).
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.0.29:
  * Add an external definition for ipmi_malloc_shutdown()
  * Pass 0 to snprintf size when calculating real size
  * selector: Fix a signed/unsigned comparison
  * selector: Fix handling if pselect() returns 0
  * selector: Return the right value for timer already in use
  * selector: Cause the read handler to be called on an exception
  * selector: Fix multi-threading issues
  * selector: Add an selector call to install a sigmask
  * For for brokenness with fork() and epoll()
  * Fix a deadlock when freeing a running timer
  * lanserv: Allow individual group extensions to be registered
  * Include readline history headers where needed
* Mon Jan 20 2020 Josef Möllers <josef.moellers@suse.com>
- Update to latest version 2.0.28
  * Fixed a number of potential buffer overruns by appending a NUL
    character to strncpy'd strings.
  * switched from editline to readline
  * some variable and function renaming to avoid leading
    underscores
  * more changes, no documentation available (ChangeLog file
    is unchanged!)
  * Two patches now obsolete.
  [OpenIPMI-2.0.25..HEAD_git.diff,
  0003-Apply-OpenIPMI-2.0.21-nobundle.patch.patch,
  OpenIPMI-2.0.28.tar.gz]
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Remove em dashes from summaries.
- Implement shared library packaging policy.
* Tue Sep 11 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Ensure neutrality of description.
- Update unspecific summaries of subpackages.
- Drop --with-pic which is only relevant for static libs.
- Speedier /usr/bin/find call.
* Fri Sep  7 2018 trenn@suse.de
- Update to latest version 2.0.25 plus latest fixes (fate#326195):
- A    OpenIPMI-2.0.25..HEAD_git.diff
  Patch to latest git commit:
  commit 4ac55d7dc7016c9e5f0c474f69f4e64e7aacac42
  Date:   Wed Jul 18 13:59:29 2018 -0500
    unix: Add a way to clear fd handlers with no callbacks
  I had to manually edit git diff v2.0.25.. and remove .gitignore deletion
  to patch succesfully. Build service wants to have the original
  .tar.gz tarball from sourceforge.
  I also had to add the bootstrap file which seem to exist in git sources
  but not in the exported tarball, even it is not listed in .gitignore:
  A bootstrap
  OAD
  0001-Apply-OpenIPMI-2.0.18-pthread-pkgconfig.patch.patch
- Adjusted patches:
  M    0003-Apply-OpenIPMI-2.0.21-nobundle.patch.patch
  M    fix-conversions.patch
  M    OpenIPMI-prefer_perl_vendor.patch
  M    openipmi-tinfo.patch
- Fix build service error (use /usr/bin/python3 in shebang instead of env
  A    use_python3_shebang
- Build documentation (IPMI.pdf) ourselves as IPMI.pdf vanished from sources
  For this quite some build requires had to be added as well
  A    fix_dia_version_detection.patch
* Wed Jul 25 2018 dimstar@opensuse.org
- Replace usage of deprecated py_sitedir macro with
  python_sitearch.
* Fri Jan 19 2018 josef.moellers@suse.com
- * added a section defining IPMI_SI_MODULE_NAME to sysconfig.ipmi
  * added code to OpenIPMI.spec/%%install to modify sysconfig.ipmi
    according to architecture
  * modified openipmi-helper to load "sysconfig.ipmi" AFTER setting
    default IPMI_SI_MODULE_NAME=ipmi_si
  [bsc#1059820, OpenIPMI.spec, openipmi-helper, sysconfig.ipmi]
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Sep 25 2017 josef.moellers@suse.com
- Upgrade to 2.0.24
  * Mainly code cleanup and small rewrites.
  * Variable renaming IPMI_... to OPENIPMI_...
  * Improved internal error handling
  * IPv6 support added/completed.
  [fate#322830, OpenIMPI-add-libncurses.patch,
  OpenIPMI-no-return-in-nonvoid-function.patch]
* Tue Jun 27 2017 tchvatal@suse.com
- Version update to lates trelease 2.0.23:
  * There is no longer actively updated changelog
  * Various bugfixes since last git pull from 2016-02-26
- Drop OpenIPMI-libtool.patch which was merged upstream
- Drop OpenIPMI_2.0.21_to_HEAD.patch patch as it is no longer
  needed
- Add patch openipmi-tinfo.patch to detect tinfo properly
- Add patch to fix OpenIPMIpthread pc file (from Fedora)
  0001-Apply-OpenIPMI-2.0.18-pthread-pkgconfig.patch.patch
- Add patch to not bundle libedit (from Fedora)
  0003-Apply-OpenIPMI-2.0.21-nobundle.patch.patch
* Wed Sep 14 2016 fgerling@suse.com
- Update spec file to properly install sysconfig.ipmi (bsc#989985, bsc#988443)
* Tue Mar  8 2016 dimstar@opensuse.org
- Remove one occurence of perl_requires: once is sufficient.
* Mon Mar  7 2016 trenn@suse.de
- Fix perl requires by using the pre-defined macro (bsc#969576)
* Fri Feb 26 2016 trenn@suse.de
- Update to latest git commit:
  a01bbe94efff3a5f239b3b5440c8..052d36ec88515c1b1177faa442833e3
  Add: OpenIPMI_2.0.21_to_HEAD.patch
  Removed modifications for:
  - lanserv/ipmi_sim_chassiscontrol
  - lanserv/marvell-bmc/TODO
  due to git repo inconsistencies
- Some spec file cleanups obs complained about
  - > also spec-cleaner run through
* Sat Feb  7 2015 dimstar@opensuse.org
- Do not try to register/deregister OpenIPMI.info.gz in post/postun
  of the devel package: we do not install such a file.
* Sat Dec 27 2014 Led <ledest@gmail.com>
- fix bashisms in openipmi-helper script
* Wed Nov 19 2014 dimstar@opensuse.org
- Replace systemd BuildRequires with pkgconfig(systemd): we do not
  require the full installation / dep chain of systemd.
* Sat Oct 25 2014 p.drouand@gmail.com
- Use systemd instead of sysvinit
  + Add ipmi.service
  + Add openipmi-helper to keep capabilities of sysvinit script
  + Add systemd related macros
- Remove obsolete/depreciated macros
* Thu Jul 10 2014 trenn@suse.de
- Split OpenIPMI into base package and OpenIPMI-python
  OpenIPMI-python gets OpenIPMI python library and openipmigui which is
  a python based gui.
  Like above the OpenIPMI base package does not need python-tk and tix
  packages any more.
* Thu Feb 13 2014 kkaempf@suse.com
- Update to 2.0.21
  Bugfix release
  - marvell: Add a command to directly set the duty cycle of the fans.
  - The IANA numbers are supposed to be in bytes 2-4 off responses to
    IANA commands, but they were not being put there.  Fix this in the
    main IANA handling to do this automatically, and modify the
    command handling to strip the IANA from the command and add it to
    a message field.  This makes handling of IANA commands more
    natural and allows standard message response generation to work.
  - Drop upstreamed patches:
    tcl-includes-moved.patch, new-names-for-new-variables,
    OpenIPMI-popt.patch, OpenIPMI-2.0.16-larger-ipmibuf.patch,
    do-fclose.patch, bug-854693_segv_sol.patch
* Thu Jan  9 2014 trenn@suse.de
- Cleanup patches:
  Drop: fix-devel-deps.patch
  Add changelog to most of the patches and submitted them mainline.
  Add: bug-854693_segv_sol.patch
  bnc#854693
* Fri Oct  4 2013 kkaempf@suse.com
- Fix SLE 11 build
* Thu Nov 15 2012 kkaempf@suse.com
- Update to 2.0.20-rc1
  * Rename lanserv_emu to ipmi_sim, and modify ipmi_sim to use
    the OS handler.
  * lanserv, man: Did a massive restructure of lanserv and the
    IPMI simulator for supporting a VM interface.
  * Many bugs fixed
- Suffix all patches with .patch
* Wed Sep 12 2012 coolo@suse.com
- use %%perl_requires
* Wed Sep  5 2012 duwe@suse.com
- fix bnc#714634
* Tue Nov 15 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct 23 2011 pascal.bleser@opensuse.org
- fix mtime on python .pyc files
- remove python .pyo files (they're useless)
- add reload to init script, which fails with exit code 3 as it is not
  implemented
- update to 2.0.19 (cumulated):
  * ipmi.init - Initscripts should be idempotent, meaning you can safely call
    "start" multiple times in a row and receive a success each time if the
    service is running. This requirement is mentioned in the LSB Spec, version
    3.1, section 20.2.
  * lib/sensor.c: Change the "share count" checking to check if share count is
    > 1, not > 0, because some silly machines set the value to one when they
    should set it to zero, and one is a silly setting
  * add a cache option
* Sun Jan 16 2011 aj@suse.de
- Buildrequire python-xml instead of dropped pyxml.
* Thu Mar 11 2010 duwe@suse.de
- compile and dependency fixes
  (bnc#388026,bnc#529028,bnc#497595,bnc#552480)
- use a large buffer for SoL (bnc#587029)
* Sun Nov 22 2009 ro@suse.de
- use py_sitedir macro in filelist
* Fri Nov 20 2009 duwe@suse.de
- update to version 2.0.16, per FATE#307244
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Mon Mar  2 2009 crrodriguez@suse.de
- save 3MB by removing static libraries and "la" files
* Thu Sep 11 2008 kukuk@suse.de
- Update to 2.0.14 [fate#304439]
- fix at least the worst bugs in init script
* Tue May  6 2008 coolo@suse.de
- return in non-void functions
* Tue Apr 15 2008 schwab@suse.de
- Fix popt configure check.
* Mon Apr 14 2008 schwab@suse.de
- Work around misuse of libtool.
* Sun Apr  6 2008 coolo@suse.de
- build with latest tcl, reduce build requires
* Wed Jan 16 2008 duwe@suse.de
- Update to 2.0.13
  + better sensors support
  + numerous bug fixes, including #310247
- fixed bug#156215
* Fri Apr 20 2007 aj@suse.de
- Package does not need latex for normal building, remove build
  dependency.
* Mon Mar 26 2007 rguenther@suse.de
- package .la and .so file in OpenIPMI-devel package only
- add gdbm-devel BuildRequires
* Mon Feb  5 2007 duwe@suse.de
- fix not-really-shadowing variable with questionable behaviour
  (reported in Bug #232439)
* Wed Dec 20 2006 coyli@suse.de
- fix misconfigured destination library directory for perl
  and python code.
- add openssl-devel and ncurse-devel in Build Requires of
  OpenIPMI-devel.
* Tue Nov  7 2006 coyli@suse.de
- fix deadlock in openipmigui (BUG #206661)
- get openssl linked in
- remove compiling warning in source code
- modify licnese from GPL to LGPL
- fix an out of range looping bug, which chould cause crash
  to programs linked with OpenIPMI library
* Thu Sep 14 2006 duwe@suse.de
- Update to 2.0.7 (thanks, coly)
  + new front-ends, some graphical ("openipmigui")
  + various bugfixes
  + new FRU interface
  + tcl bindings added
  site_perl spared thanks to Rudi.
* Mon May 29 2006 kukuk@suse.de
- ipmi init script: Replace /sbin/udev with /sbin/udevd [#174010]
* Fri Mar  3 2006 duwe@suse.de
- update to 1.4.26
  - various small bug and memory leak fixes
  - fix local operation on ATCA
  - add support for multiple IPMB channels with different IPMB
    addresses
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 duwe@suse.de
- Add %%insserv_prereq and %%fillup_prereq fixing Bug #140314
* Mon Dec 19 2005 ro@suse.de
- fixed filelist
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Oct 26 2005 duwe@suse.de
- add patches by matt to sync with upstream (#128770)
* Mon Oct 10 2005 duwe@suse.de
- rc script name change openipmi->ipmi (Bug #120227)
- default start in runlevels 2 3 5 (Bug #121651)
* Thu Sep 22 2005 duwe@suse.de
- Update to version 1.4.19 (#117699)
- add initscripts (#117103)
* Mon Jun  6 2005 mrueckert@suse.de
- Update to version 1.4.16
* Tue May 10 2005 meissner@suse.de
- fixed potential 2 byte overflow due to bug in strncpy().
* Sat Mar 26 2005 nashif@suse.de
- Fixed license in include file (#74351)
* Fri Feb 18 2005 nashif@suse.de
- Update to 1.3.17
- Split package
* Sat Jan  8 2005 nashif@suse.de
- Fixed installation of info files
* Tue Jan  4 2005 nashif@suse.de
- Update to version 1.3.16
* Thu Oct 28 2004 nashif@suse.de
- Updated to version 1.3.11
* Tue Aug 10 2004 nashif@suse.de
- Updated to version 1.3.9
* Tue Jun  8 2004 nashif@suse.de
- Updated to version 1.3.8
* Wed May  5 2004 nashif@suse.de
- Added a way to get the number of entries and free
  bytes in the SEL.
* Fri Apr 30 2004 nashif@suse.de
- Fixes by author:
  * lib/sel.c: Fixed a bug in the sel get where the info allocated
  can go away before the operation returns, but the info is used
  after the operation returns.
  * lib/sensor.c: Fix the hysteresis setting to send a message that
  is the right size.
* Wed Apr 28 2004 nashif@suse.de
- Updated to 1.3.6 (as per bug #38602)
* Mon Mar 22 2004 nashif@suse.de
- Enabled sources again
- files with legal issues have been removed upstream
* Sun Mar 21 2004 nashif@suse.de
- Update to release 1.2.21
* Fri Feb 27 2004 tsieden@suse.de
- update to release 1.2.7
- replaced test_md2.c with a dummy, switched to a nosrc.rpm
  to avoid legal problems
* Mon Oct 27 2003 kukuk@suse.de
- Don't link static libraries in shared one without -fPIC compiled
- Fix building on lib64 architectures
* Thu Oct 23 2003 tsieden@suse.de
- branched -devel package
* Fri Oct 17 2003 tsieden@suse.de
- initial release 1.1.4
